@@ -4,7 +4,7 @@ from users_and_computers.models import RiskAssignment
 
 
 class RiskVMPanel(PluginTemplateExtension):
-    model = 'plugins.users_and_computers.risk'
+    model = 'plugins.users_and_computers.aduser'
     # model = 'virtualization.virtualmachine'
 
     def right_page(self):
@@ -24,10 +24,9 @@ class RiskVMPanel(PluginTemplateExtension):
             'risks': risks
         })
 
-
 class RiskDevicePanel(PluginTemplateExtension):
     # model = 'dcim.device'
-    model = 'plugins.users_and_computers.riskrelation'
+    model = 'plugins.users_and_computers.ad_users'
 
     def right_page(self):
         risk = self.context['object']
